@@ -5,6 +5,7 @@
 #include "src/Utils.h"
 #include "src/Channel.h"
 #include "src/Terrestrial/TerrestrialChannel.h"
+#include "src/MpegTsEnums.h"
 #include "src/Satellite/SatelliteChannel.h"
 #include "src/Cable/CableChannel.h"
 
@@ -39,7 +40,7 @@ DVBChannelListReader* dvb_channel_list_reader_construct (GType object_type, GFil
 	GParameter * __params;
 	GParameter * __params_it;
 	DVBChannelListReader * self;
-	g_return_val_if_fail (G_IS_FILE (file), NULL);
+	g_return_val_if_fail (file != NULL, NULL);
 	__params = g_new0 (GParameter, 2);
 	__params_it = __params;
 	__params_it->name = "ChannelFile";
@@ -70,7 +71,7 @@ DVBChannelList* dvb_channel_list_reader_read (DVBChannelListReader* self, GError
 	char* contents;
 	DVBChannelList* channels;
 	DVBChannelList* _tmp4;
-	g_return_val_if_fail (DVB_IS_CHANNEL_LIST_READER (self), NULL);
+	g_return_val_if_fail (self != NULL, NULL);
 	inner_error = NULL;
 	contents = dvb_utils_read_file_contents (self->priv->_ChannelFile, &inner_error);
 	if (inner_error != NULL) {
@@ -80,9 +81,9 @@ DVBChannelList* dvb_channel_list_reader_read (DVBChannelListReader* self, GError
 	if (contents == NULL) {
 		DVBChannelList* _tmp0;
 		_tmp0 = NULL;
-		return (_tmp0 = NULL, (contents = (g_free (contents), NULL)), _tmp0);
+		return (_tmp0 = NULL, contents = (g_free (contents), NULL), _tmp0);
 	}
-	channels = dvb_channel_list_new (self->priv->_ChannelFile);
+	channels = dvb_channel_list_new ();
 	{
 		char** line_collection;
 		int line_collection_length1;
@@ -93,7 +94,7 @@ DVBChannelList* dvb_channel_list_reader_read (DVBChannelListReader* self, GError
 			const char* _tmp3;
 			char* line;
 			_tmp3 = NULL;
-			line = (_tmp3 = *line_it, (_tmp3 == NULL ? NULL : g_strdup (_tmp3)));
+			line = (_tmp3 = *line_it, (_tmp3 == NULL) ? NULL : g_strdup (_tmp3));
 			{
 				if (strlen (line) > 0) {
 					DVBChannel* c;
@@ -103,49 +104,56 @@ DVBChannelList* dvb_channel_list_reader_read (DVBChannelListReader* self, GError
 						DVBChannel* _tmp1;
 						_tmp2 = NULL;
 						_tmp1 = NULL;
-						dvb_channel_list_add (channels, (_tmp2 = (_tmp1 = c, c = NULL, _tmp1)));
-						(_tmp2 == NULL ? NULL : (_tmp2 = (g_object_unref (_tmp2), NULL)));
+						dvb_channel_list_add (channels, _tmp2 = (_tmp1 = c, c = NULL, _tmp1));
+						(_tmp2 == NULL) ? NULL : (_tmp2 = (g_object_unref (_tmp2), NULL));
 					} else {
 						g_warning ("ChannelListReader.vala:27: Could not parse channel");
 					}
-					(c == NULL ? NULL : (c = (g_object_unref (c), NULL)));
+					(c == NULL) ? NULL : (c = (g_object_unref (c), NULL));
 				}
 				line = (g_free (line), NULL);
 			}
 		}
-		line_collection = (_vala_array_free (line_collection, line_collection_length1, ((GDestroyNotify) (g_free))), NULL);
+		line_collection = (_vala_array_free (line_collection, line_collection_length1, (GDestroyNotify) g_free), NULL);
 	}
 	_tmp4 = NULL;
-	return (_tmp4 = channels, (contents = (g_free (contents), NULL)), _tmp4);
+	return (_tmp4 = channels, contents = (g_free (contents), NULL), _tmp4);
 }
 
 
 static DVBChannel* dvb_channel_list_reader_parse_line (DVBChannelListReader* self, const char* line) {
 	DVBChannel* c;
-	DVBAdapterType _tmp3;
-	g_return_val_if_fail (DVB_IS_CHANNEL_LIST_READER (self), NULL);
+	g_return_val_if_fail (self != NULL, NULL);
 	g_return_val_if_fail (line != NULL, NULL);
 	c = NULL;
-	_tmp3 = self->priv->_Type;
-	if (_tmp3 == DVB_ADAPTER_TYPE_DVB_T)
-	do {
-		DVBChannel* _tmp0;
-		_tmp0 = NULL;
-		c = (_tmp0 = DVB_CHANNEL (dvb_channel_list_reader_parse_terrestrial_channel (line)), (c == NULL ? NULL : (c = (g_object_unref (c), NULL))), _tmp0);
-		break;
-	} while (0); else if (_tmp3 == DVB_ADAPTER_TYPE_DVB_S)
-	do {
-		DVBChannel* _tmp1;
-		_tmp1 = NULL;
-		c = (_tmp1 = DVB_CHANNEL (dvb_channel_list_reader_parse_satellite_channel (line)), (c == NULL ? NULL : (c = (g_object_unref (c), NULL))), _tmp1);
-		break;
-	} while (0); else if (_tmp3 == DVB_ADAPTER_TYPE_DVB_C)
-	do {
-		DVBChannel* _tmp2;
-		_tmp2 = NULL;
-		c = (_tmp2 = DVB_CHANNEL (dvb_channel_list_reader_parse_cable_channel (line)), (c == NULL ? NULL : (c = (g_object_unref (c), NULL))), _tmp2);
-		break;
-	} while (0);
+	switch (self->priv->_Type) {
+		case DVB_ADAPTER_TYPE_DVB_T:
+		{
+			DVBChannel* _tmp0;
+			_tmp0 = NULL;
+			c = (_tmp0 = (DVBChannel*) dvb_channel_list_reader_parse_terrestrial_channel (line), (c == NULL) ? NULL : (c = (g_object_unref (c), NULL)), _tmp0);
+			break;
+		}
+		case DVB_ADAPTER_TYPE_DVB_S:
+		{
+			DVBChannel* _tmp1;
+			_tmp1 = NULL;
+			c = (_tmp1 = (DVBChannel*) dvb_channel_list_reader_parse_satellite_channel (line), (c == NULL) ? NULL : (c = (g_object_unref (c), NULL)), _tmp1);
+			break;
+		}
+		case DVB_ADAPTER_TYPE_DVB_C:
+		{
+			DVBChannel* _tmp2;
+			_tmp2 = NULL;
+			c = (_tmp2 = (DVBChannel*) dvb_channel_list_reader_parse_cable_channel (line), (c == NULL) ? NULL : (c = (g_object_unref (c), NULL)), _tmp2);
+			break;
+		}
+		default:
+		{
+			g_critical ("ChannelListReader.vala:50: Unknown adapter type");
+			break;
+		}
+	}
 	return c;
 }
 
@@ -175,50 +183,50 @@ static DVBTerrestrialChannel* dvb_channel_list_reader_parse_terrestrial_channel
 	val = NULL;
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	while ((val = (_tmp2 = (_tmp1 = fields[i], (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (val = (g_free (val), NULL)), _tmp2)) != NULL) {
+	while ((val = (_tmp2 = (_tmp1 = fields[i], (_tmp1 == NULL) ? NULL : g_strdup (_tmp1)), val = (g_free (val), NULL), _tmp2)) != NULL) {
 		if (i == 0) {
 			if (g_utf8_validate (val, -1, NULL)) {
-				dvb_channel_set_Name (DVB_CHANNEL (channel), val);
+				dvb_channel_set_Name ((DVBChannel*) channel, val);
 			} else {
-				g_warning ("ChannelListReader.vala:71: Bad UTF-8 encoded channel name");
-				dvb_channel_set_Name (DVB_CHANNEL (channel), "Bad encoding");
+				g_warning ("ChannelListReader.vala:75: Bad UTF-8 encoded channel name");
+				dvb_channel_set_Name ((DVBChannel*) channel, "Bad encoding");
 			}
 		} else {
 			if (i == 1) {
-				dvb_channel_set_Frequency (DVB_CHANNEL (channel), ((guint) (atoi (val))));
+				dvb_channel_set_Frequency ((DVBChannel*) channel, (guint) atoi (val));
 			} else {
 				if (i == 2) {
-					dvb_terrestrial_channel_set_Inversion (channel, dvb_channel_list_reader_get_value_with_prefix (DVB_TYPE_DVB_SRC_INVERSION, val, "DVB_DVB_SRC_INVERSION_"));
+					dvb_terrestrial_channel_set_Inversion (channel, (DVBDvbSrcInversion) dvb_channel_list_reader_get_value_with_prefix (DVB_TYPE_DVB_SRC_INVERSION, val, "DVB_DVB_SRC_INVERSION_"));
 				} else {
 					if (i == 3) {
-						dvb_terrestrial_channel_set_Bandwidth (channel, dvb_channel_list_reader_get_value_with_prefix (DVB_TYPE_DVB_SRC_BANDWIDTH, val, "DVB_DVB_SRC_BANDWIDTH_"));
+						dvb_terrestrial_channel_set_Bandwidth (channel, (DVBDvbSrcBandwidth) dvb_channel_list_reader_get_value_with_prefix (DVB_TYPE_DVB_SRC_BANDWIDTH, val, "DVB_DVB_SRC_BANDWIDTH_"));
 					} else {
 						if (i == 4) {
-							dvb_terrestrial_channel_set_CodeRateHP (channel, dvb_channel_list_reader_get_value_with_prefix (DVB_TYPE_DVB_SRC_CODE_RATE, val, "DVB_DVB_SRC_CODE_RATE_"));
+							dvb_terrestrial_channel_set_CodeRateHP (channel, (DVBDvbSrcCodeRate) dvb_channel_list_reader_get_value_with_prefix (DVB_TYPE_DVB_SRC_CODE_RATE, val, "DVB_DVB_SRC_CODE_RATE_"));
 						} else {
 							if (i == 5) {
-								dvb_terrestrial_channel_set_CodeRateLP (channel, dvb_channel_list_reader_get_value_with_prefix (DVB_TYPE_DVB_SRC_CODE_RATE, val, "DVB_DVB_SRC_CODE_RATE_"));
+								dvb_terrestrial_channel_set_CodeRateLP (channel, (DVBDvbSrcCodeRate) dvb_channel_list_reader_get_value_with_prefix (DVB_TYPE_DVB_SRC_CODE_RATE, val, "DVB_DVB_SRC_CODE_RATE_"));
 							} else {
 								if (i == 6) {
-									dvb_terrestrial_channel_set_Constellation (channel, dvb_channel_list_reader_get_value_with_prefix (DVB_TYPE_DVB_SRC_MODULATION, val, "DVB_DVB_SRC_MODULATION_"));
+									dvb_terrestrial_channel_set_Constellation (channel, (DVBDvbSrcModulation) dvb_channel_list_reader_get_value_with_prefix (DVB_TYPE_DVB_SRC_MODULATION, val, "DVB_DVB_SRC_MODULATION_"));
 								} else {
 									if (i == 7) {
-										dvb_terrestrial_channel_set_TransmissionMode (channel, dvb_channel_list_reader_get_value_with_prefix (DVB_TYPE_DVB_SRC_TRANSMISSION_MODE, val, "DVB_DVB_SRC_TRANSMISSION_MODE_"));
+										dvb_terrestrial_channel_set_TransmissionMode (channel, (DVBDvbSrcTransmissionMode) dvb_channel_list_reader_get_value_with_prefix (DVB_TYPE_DVB_SRC_TRANSMISSION_MODE, val, "DVB_DVB_SRC_TRANSMISSION_MODE_"));
 									} else {
 										if (i == 8) {
-											dvb_terrestrial_channel_set_GuardInterval (channel, dvb_channel_list_reader_get_value_with_prefix (DVB_TYPE_DVB_SRC_GUARD, val, "DVB_DVB_SRC_GUARD_"));
+											dvb_terrestrial_channel_set_GuardInterval (channel, (DVBDvbSrcGuard) dvb_channel_list_reader_get_value_with_prefix (DVB_TYPE_DVB_SRC_GUARD, val, "DVB_DVB_SRC_GUARD_"));
 										} else {
 											if (i == 9) {
-												dvb_terrestrial_channel_set_Hierarchy (channel, dvb_channel_list_reader_get_value_with_prefix (DVB_TYPE_DVB_SRC_HIERARCHY, val, "DVB_DVB_SRC_HIERARCHY_"));
+												dvb_terrestrial_channel_set_Hierarchy (channel, (DVBDvbSrcHierarchy) dvb_channel_list_reader_get_value_with_prefix (DVB_TYPE_DVB_SRC_HIERARCHY, val, "DVB_DVB_SRC_HIERARCHY_"));
 											} else {
 												if (i == 10) {
-													dvb_channel_set_VideoPID (DVB_CHANNEL (channel), ((guint) (atoi (val))));
+													dvb_channel_set_VideoPID ((DVBChannel*) channel, (guint) atoi (val));
 												} else {
 													if (i == 11) {
-														dvb_channel_set_AudioPID (DVB_CHANNEL (channel), ((guint) (atoi (val))));
+														dvb_channel_set_AudioPID ((DVBChannel*) channel, (guint) atoi (val));
 													} else {
 														if (i == 12) {
-															dvb_channel_set_Sid (DVB_CHANNEL (channel), ((guint) (atoi (val))));
+															dvb_channel_set_Sid ((DVBChannel*) channel, (guint) atoi (val));
 														}
 													}
 												}
@@ -235,7 +243,7 @@ static DVBTerrestrialChannel* dvb_channel_list_reader_parse_terrestrial_channel
 		i++;
 	}
 	_tmp3 = NULL;
-	return (_tmp3 = channel, (fields = (_vala_array_free (fields, fields_length1, ((GDestroyNotify) (g_free))), NULL)), (val = (g_free (val), NULL)), _tmp3);
+	return (_tmp3 = channel, fields = (_vala_array_free (fields, fields_length1, (GDestroyNotify) g_free), NULL), val = (g_free (val), NULL), _tmp3);
 }
 
 
@@ -262,18 +270,18 @@ static DVBSatelliteChannel* dvb_channel_list_reader_parse_satellite_channel (con
 	val = NULL;
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	while ((val = (_tmp2 = (_tmp1 = fields[i], (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (val = (g_free (val), NULL)), _tmp2)) != NULL) {
+	while ((val = (_tmp2 = (_tmp1 = fields[i], (_tmp1 == NULL) ? NULL : g_strdup (_tmp1)), val = (g_free (val), NULL), _tmp2)) != NULL) {
 		if (i == 0) {
 			if (g_utf8_validate (val, -1, NULL)) {
-				dvb_channel_set_Name (DVB_CHANNEL (channel), val);
+				dvb_channel_set_Name ((DVBChannel*) channel, val);
 			} else {
-				g_warning ("ChannelListReader.vala:132: Bad UTF-8 encoded channel name");
-				dvb_channel_set_Name (DVB_CHANNEL (channel), "Bad encoding");
+				g_warning ("ChannelListReader.vala:136: Bad UTF-8 encoded channel name");
+				dvb_channel_set_Name ((DVBChannel*) channel, "Bad encoding");
 			}
 		} else {
 			if (i == 1) {
 				/* frequency is stored in MHz*/
-				dvb_channel_set_Frequency (DVB_CHANNEL (channel), ((guint) ((atoi (val) * 1000))));
+				dvb_channel_set_Frequency ((DVBChannel*) channel, (guint) (atoi (val) * 1000));
 			} else {
 				if (i == 2) {
 					dvb_satellite_channel_set_Polarization (channel, val);
@@ -284,16 +292,16 @@ static DVBSatelliteChannel* dvb_channel_list_reader_parse_satellite_channel (con
 					} else {
 						if (i == 4) {
 							/* symbol rate is stored in kBaud*/
-							dvb_satellite_channel_set_SymbolRate (channel, ((guint) (atoi (val))));
+							dvb_satellite_channel_set_SymbolRate (channel, (guint) atoi (val));
 						} else {
 							if (i == 5) {
-								dvb_channel_set_VideoPID (DVB_CHANNEL (channel), ((guint) (atoi (val))));
+								dvb_channel_set_VideoPID ((DVBChannel*) channel, (guint) atoi (val));
 							} else {
 								if (i == 6) {
-									dvb_channel_set_AudioPID (DVB_CHANNEL (channel), ((guint) (atoi (val))));
+									dvb_channel_set_AudioPID ((DVBChannel*) channel, (guint) atoi (val));
 								} else {
 									if (i == 7) {
-										dvb_channel_set_Sid (DVB_CHANNEL (channel), ((guint) (atoi (val))));
+										dvb_channel_set_Sid ((DVBChannel*) channel, (guint) atoi (val));
 									}
 								}
 							}
@@ -305,7 +313,7 @@ static DVBSatelliteChannel* dvb_channel_list_reader_parse_satellite_channel (con
 		i++;
 	}
 	_tmp3 = NULL;
-	return (_tmp3 = channel, (fields = (_vala_array_free (fields, fields_length1, ((GDestroyNotify) (g_free))), NULL)), (val = (g_free (val), NULL)), _tmp3);
+	return (_tmp3 = channel, fields = (_vala_array_free (fields, fields_length1, (GDestroyNotify) g_free), NULL), val = (g_free (val), NULL), _tmp3);
 }
 
 
@@ -332,38 +340,38 @@ static DVBCableChannel* dvb_channel_list_reader_parse_cable_channel (const char*
 	val = NULL;
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	while ((val = (_tmp2 = (_tmp1 = fields[i], (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (val = (g_free (val), NULL)), _tmp2)) != NULL) {
+	while ((val = (_tmp2 = (_tmp1 = fields[i], (_tmp1 == NULL) ? NULL : g_strdup (_tmp1)), val = (g_free (val), NULL), _tmp2)) != NULL) {
 		if (i == 0) {
 			if (g_utf8_validate (val, -1, NULL)) {
-				dvb_channel_set_Name (DVB_CHANNEL (channel), val);
+				dvb_channel_set_Name ((DVBChannel*) channel, val);
 			} else {
-				g_warning ("ChannelListReader.vala:177: Bad UTF-8 encoded channel name");
-				dvb_channel_set_Name (DVB_CHANNEL (channel), "Bad encoding");
+				g_warning ("ChannelListReader.vala:181: Bad UTF-8 encoded channel name");
+				dvb_channel_set_Name ((DVBChannel*) channel, "Bad encoding");
 			}
 		} else {
 			if (i == 1) {
-				dvb_channel_set_Frequency (DVB_CHANNEL (channel), ((guint) (atoi (val))));
+				dvb_channel_set_Frequency ((DVBChannel*) channel, (guint) atoi (val));
 			} else {
 				if (i == 2) {
-					dvb_cable_channel_set_Inversion (channel, dvb_channel_list_reader_get_value_with_prefix (DVB_TYPE_DVB_SRC_INVERSION, val, "DVB_DVB_SRC_INVERSION_"));
+					dvb_cable_channel_set_Inversion (channel, (DVBDvbSrcInversion) dvb_channel_list_reader_get_value_with_prefix (DVB_TYPE_DVB_SRC_INVERSION, val, "DVB_DVB_SRC_INVERSION_"));
 				} else {
 					if (i == 3) {
-						dvb_cable_channel_set_SymbolRate (channel, ((guint) (atoi (val))));
+						dvb_cable_channel_set_SymbolRate (channel, (guint) atoi (val));
 					} else {
 						if (i == 4) {
-							dvb_cable_channel_set_CodeRate (channel, dvb_channel_list_reader_get_value_with_prefix (DVB_TYPE_DVB_SRC_CODE_RATE, val, "DVB_DVB_SRC_CODE_RATE_"));
+							dvb_cable_channel_set_CodeRate (channel, (DVBDvbSrcCodeRate) dvb_channel_list_reader_get_value_with_prefix (DVB_TYPE_DVB_SRC_CODE_RATE, val, "DVB_DVB_SRC_CODE_RATE_"));
 						} else {
 							if (i == 5) {
-								dvb_cable_channel_set_Modulation (channel, dvb_channel_list_reader_get_value_with_prefix (DVB_TYPE_DVB_SRC_MODULATION, val, "DVB_DVB_SRC_MODULATION_"));
+								dvb_cable_channel_set_Modulation (channel, (DVBDvbSrcModulation) dvb_channel_list_reader_get_value_with_prefix (DVB_TYPE_DVB_SRC_MODULATION, val, "DVB_DVB_SRC_MODULATION_"));
 							} else {
 								if (i == 6) {
-									dvb_channel_set_VideoPID (DVB_CHANNEL (channel), ((guint) (atoi (val))));
+									dvb_channel_set_VideoPID ((DVBChannel*) channel, (guint) atoi (val));
 								} else {
 									if (i == 7) {
-										dvb_channel_set_AudioPID (DVB_CHANNEL (channel), ((guint) (atoi (val))));
+										dvb_channel_set_AudioPID ((DVBChannel*) channel, (guint) atoi (val));
 									} else {
 										if (i == 8) {
-											dvb_channel_set_Sid (DVB_CHANNEL (channel), ((guint) (atoi (val))));
+											dvb_channel_set_Sid ((DVBChannel*) channel, (guint) atoi (val));
 										}
 									}
 								}
@@ -376,7 +384,7 @@ static DVBCableChannel* dvb_channel_list_reader_parse_cable_channel (const char*
 		i++;
 	}
 	_tmp3 = NULL;
-	return (_tmp3 = channel, (fields = (_vala_array_free (fields, fields_length1, ((GDestroyNotify) (g_free))), NULL)), (val = (g_free (val), NULL)), _tmp3);
+	return (_tmp3 = channel, fields = (_vala_array_free (fields, fields_length1, (GDestroyNotify) g_free), NULL), val = (g_free (val), NULL), _tmp3);
 }
 
 
@@ -386,12 +394,12 @@ static gint dvb_channel_list_reader_get_value_with_prefix (GType enumtype, const
 	g_return_val_if_fail (name != NULL, 0);
 	g_return_val_if_fail (prefix != NULL, 0);
 	_tmp0 = NULL;
-	return (_tmp1 = dvb_utils_get_value_by_name_from_enum (enumtype, (_tmp0 = g_strconcat (prefix, name, NULL))), (_tmp0 = (g_free (_tmp0), NULL)), _tmp1);
+	return (_tmp1 = dvb_utils_get_value_by_name_from_enum (enumtype, _tmp0 = g_strconcat (prefix, name, NULL)), _tmp0 = (g_free (_tmp0), NULL), _tmp1);
 }
 
 
 GFile* dvb_channel_list_reader_get_ChannelFile (DVBChannelListReader* self) {
-	g_return_val_if_fail (DVB_IS_CHANNEL_LIST_READER (self), NULL);
+	g_return_val_if_fail (self != NULL, NULL);
 	return self->priv->_ChannelFile;
 }
 
@@ -399,24 +407,24 @@ GFile* dvb_channel_list_reader_get_ChannelFile (DVBChannelListReader* self) {
 static void dvb_channel_list_reader_set_ChannelFile (DVBChannelListReader* self, GFile* value) {
 	GFile* _tmp2;
 	GFile* _tmp1;
-	g_return_if_fail (DVB_IS_CHANNEL_LIST_READER (self));
+	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_ChannelFile = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_ChannelFile == NULL ? NULL : (self->priv->_ChannelFile = (g_object_unref (self->priv->_ChannelFile), NULL))), _tmp2);
-	g_object_notify (((GObject *) (self)), "ChannelFile");
+	self->priv->_ChannelFile = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : g_object_ref (_tmp1)), (self->priv->_ChannelFile == NULL) ? NULL : (self->priv->_ChannelFile = (g_object_unref (self->priv->_ChannelFile), NULL)), _tmp2);
+	g_object_notify ((GObject *) self, "ChannelFile");
 }
 
 
 DVBAdapterType dvb_channel_list_reader_get_Type (DVBChannelListReader* self) {
-	g_return_val_if_fail (DVB_IS_CHANNEL_LIST_READER (self), 0);
+	g_return_val_if_fail (self != NULL, 0);
 	return self->priv->_Type;
 }
 
 
 static void dvb_channel_list_reader_set_Type (DVBChannelListReader* self, DVBAdapterType value) {
-	g_return_if_fail (DVB_IS_CHANNEL_LIST_READER (self));
+	g_return_if_fail (self != NULL);
 	self->priv->_Type = value;
-	g_object_notify (((GObject *) (self)), "Type");
+	g_object_notify ((GObject *) self, "Type");
 }
 
 
@@ -473,7 +481,7 @@ static void dvb_channel_list_reader_instance_init (DVBChannelListReader * self)
 static void dvb_channel_list_reader_finalize (GObject* obj) {
 	DVBChannelListReader * self;
 	self = DVB_CHANNEL_LIST_READER (obj);
-	(self->priv->_ChannelFile == NULL ? NULL : (self->priv->_ChannelFile = (g_object_unref (self->priv->_ChannelFile), NULL)));
+	(self->priv->_ChannelFile == NULL) ? NULL : (self->priv->_ChannelFile = (g_object_unref (self->priv->_ChannelFile), NULL));
 	G_OBJECT_CLASS (dvb_channel_list_reader_parent_class)->finalize (obj);
 }
 
@@ -489,16 +497,16 @@ GType dvb_channel_list_reader_get_type (void) {
 
 
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
-	if (array != NULL && destroy_func != NULL) {
+	if ((array != NULL) && (destroy_func != NULL)) {
 		int i;
 		if (array_length >= 0)
 		for (i = 0; i < array_length; i = i + 1) {
-			if (((gpointer*) (array))[i] != NULL)
-			destroy_func (((gpointer*) (array))[i]);
+			if (((gpointer*) array)[i] != NULL)
+			destroy_func (((gpointer*) array)[i]);
 		}
 		else
-		for (i = 0; ((gpointer*) (array))[i] != NULL; i = i + 1) {
-			destroy_func (((gpointer*) (array))[i]);
+		for (i = 0; ((gpointer*) array)[i] != NULL; i = i + 1) {
+			destroy_func (((gpointer*) array)[i]);
 		}
 	}
 	g_free (array);
