@@ -35,19 +35,19 @@ static void dvb_event_finalize (DVBEvent* obj);
 
 
 static void _g_slist_free_dvb_event_audio_component_unref (GSList* self) {
-	g_slist_foreach (self, ((GFunc) (dvb_event_audio_component_unref)), NULL);
+	g_slist_foreach (self, (GFunc) dvb_event_audio_component_unref, NULL);
 	g_slist_free (self);
 }
 
 
 static void _g_slist_free_dvb_event_video_component_unref (GSList* self) {
-	g_slist_foreach (self, ((GFunc) (dvb_event_video_component_unref)), NULL);
+	g_slist_foreach (self, (GFunc) dvb_event_video_component_unref, NULL);
 	g_slist_free (self);
 }
 
 
 static void _g_slist_free_dvb_event_teletext_component_unref (GSList* self) {
-	g_slist_foreach (self, ((GFunc) (dvb_event_teletext_component_unref)), NULL);
+	g_slist_foreach (self, (GFunc) dvb_event_teletext_component_unref, NULL);
 	g_slist_free (self);
 }
 
@@ -62,13 +62,13 @@ gboolean dvb_event_has_expired (DVBEvent* self) {
 	struct tm current_utc;
 	gint64 current_time;
 	gint64 end_timestamp;
-	g_return_val_if_fail (DVB_IS_EVENT (self), FALSE);
+	g_return_val_if_fail (self != NULL, FALSE);
 	current_utc = (gmtime_r ((_tmp2 = (time (&_tmp0), _tmp0), &_tmp2), &_tmp1), _tmp1);
 	/* set day light saving time to undefined
 	 otherwise mktime will add an hour,
 	 because it respects dst*/
 	current_utc.tm_isdst = -1;
-	current_time = ((gint64) (mktime (&current_utc)));
+	current_time = (gint64) mktime (&current_utc);
 	end_timestamp = dvb_event_get_end_timestamp (self);
 	return (end_timestamp < current_time);
 }
@@ -82,12 +82,12 @@ gboolean dvb_event_is_running (DVBEvent* self) {
 	struct tm time_start;
 	gint64 timestamp_now;
 	gint64 timestamp_start;
-	g_return_val_if_fail (DVB_IS_EVENT (self), FALSE);
+	g_return_val_if_fail (self != NULL, FALSE);
 	time_now = (gmtime_r ((_tmp2 = (time (&_tmp0), _tmp0), &_tmp2), &_tmp1), _tmp1);
 	time_start = dvb_event_get_utc_start_time (self);
-	timestamp_now = ((gint64) (timegm (&time_now)));
-	timestamp_start = ((gint64) (timegm (&time_start)));
-	if (timestamp_now - timestamp_start >= 0) {
+	timestamp_now = (gint64) timegm (&time_now);
+	timestamp_start = (gint64) timegm (&time_start);
+	if ((timestamp_now - timestamp_start) >= 0) {
 		/* Has started, check if it's still running*/
 		return (!dvb_event_has_expired (self));
 	} else {
@@ -102,11 +102,11 @@ char* dvb_event_to_string (DVBEvent* self) {
 	char* _tmp0;
 	char* _tmp2;
 	char* text;
-	g_return_val_if_fail (DVB_IS_EVENT (self), NULL);
+	g_return_val_if_fail (self != NULL, NULL);
 	_tmp1 = NULL;
 	_tmp0 = NULL;
 	_tmp2 = NULL;
-	text = (_tmp2 = g_strconcat ((_tmp0 = g_strdup_printf ("ID: %u\nDate: %04u-%02u-%02u %02u:%02u:%02u\n", self->id, self->year, self->month, self->day, self->hour, self->minute, self->second)), (_tmp1 = g_strdup_printf ("Duration: %u\nName: %s\nDescription: %s\n", self->duration, self->name, self->description)), NULL), (_tmp1 = (g_free (_tmp1), NULL)), (_tmp0 = (g_free (_tmp0), NULL)), _tmp2);
+	text = (_tmp2 = g_strconcat (_tmp0 = g_strdup_printf ("ID: %u\nDate: %04u-%02u-%02u %02u:%02u:%02u\n", self->id, self->year, self->month, self->day, self->hour, self->minute, self->second), _tmp1 = g_strdup_printf ("Duration: %u\nName: %s\nDescription: %s\n", self->duration, self->name, self->description), NULL), _tmp1 = (g_free (_tmp1), NULL), _tmp0 = (g_free (_tmp0), NULL), _tmp2);
 	{
 		gint i;
 		i = 0;
@@ -115,7 +115,7 @@ char* dvb_event_to_string (DVBEvent* self) {
 			char* _tmp3;
 			_tmp4 = NULL;
 			_tmp3 = NULL;
-			text = (_tmp4 = g_strconcat (text, (_tmp3 = (g_strdup_printf ("%s ", ((DVBEventAudioComponent*) (g_slist_nth_data (self->audio_components, ((guint) (i)))))->type))), NULL), (text = (g_free (text), NULL)), _tmp4);
+			text = (_tmp4 = g_strconcat (text, _tmp3 = (g_strdup_printf ("%s ", ((DVBEventAudioComponent*) g_slist_nth_data (self->audio_components, (guint) i))->type)), NULL), text = (g_free (text), NULL), _tmp4);
 			_tmp3 = (g_free (_tmp3), NULL);
 		}
 	}
@@ -140,7 +140,7 @@ struct tm dvb_event_get_local_start_time (DVBEvent* self) {
 struct tm dvb_event_get_utc_start_time (DVBEvent* self) {
 	struct tm utc_time;
 	0;
-	utc_time = dvb_utils_create_utc_time (((gint) (self->year)), ((gint) (self->month)), ((gint) (self->day)), ((gint) (self->hour)), ((gint) (self->minute)), ((gint) (self->second)));
+	utc_time = dvb_utils_create_utc_time ((gint) self->year, (gint) self->month, (gint) self->day, (gint) self->hour, (gint) self->minute, (gint) self->second);
 	return utc_time;
 }
 
@@ -152,12 +152,19 @@ static gint64 dvb_event_get_end_timestamp (DVBEvent* self) {
 	struct tm end_time;
 	gint64 before;
 	gint64 after;
-	g_return_val_if_fail (DVB_IS_EVENT (self), 0LL);
-	end_time = dvb_utils_create_utc_time (((gint) (self->year)), ((gint) (self->month)), ((gint) (self->day)), ((gint) (self->hour)), ((gint) (self->minute)), ((gint) (self->second)));
-	before = ((gint64) (mktime (&end_time)));
-	end_time.tm_sec = end_time.tm_sec + (((gint) (self->duration)));
-	after = ((gint64) (mktime (&end_time)));
-	g_assert (after > before && after - before == self->duration);
+	gboolean _tmp0;
+	g_return_val_if_fail (self != NULL, 0LL);
+	end_time = dvb_utils_create_utc_time ((gint) self->year, (gint) self->month, (gint) self->day, (gint) self->hour, (gint) self->minute, (gint) self->second);
+	before = (gint64) mktime (&end_time);
+	end_time.tm_sec = end_time.tm_sec + ((gint) self->duration);
+	after = (gint64) mktime (&end_time);
+	_tmp0 = FALSE;
+	if (after > before) {
+		_tmp0 = (after - before) == self->duration;
+	} else {
+		_tmp0 = FALSE;
+	}
+	g_assert (_tmp0);
 	return after;
 }
 
@@ -169,21 +176,42 @@ static gint64 dvb_event_get_end_timestamp (DVBEvent* self) {
          * Compare the starting time of two events
          */
 gint dvb_event_compare (DVBEvent* event1, DVBEvent* event2) {
+	gboolean _tmp0;
 	gint64 event1_time;
 	gint64 event2_time;
-	if (event1 == NULL && event2 == NULL) {
+	_tmp0 = FALSE;
+	if (event1 == NULL) {
+		_tmp0 = event2 == NULL;
+	} else {
+		_tmp0 = FALSE;
+	}
+	if (_tmp0) {
 		return 0;
 	} else {
-		if (event1 == NULL && event2 != NULL) {
+		gboolean _tmp2;
+		_tmp2 = FALSE;
+		if (event1 == NULL) {
+			_tmp2 = event2 != NULL;
+		} else {
+			_tmp2 = FALSE;
+		}
+		if (_tmp2) {
 			return +1;
 		} else {
-			if (event1 != NULL && event2 == NULL) {
+			gboolean _tmp4;
+			_tmp4 = FALSE;
+			if (event1 != NULL) {
+				_tmp4 = event2 == NULL;
+			} else {
+				_tmp4 = FALSE;
+			}
+			if (_tmp4) {
 				return -1;
 			}
 		}
 	}
-	event1_time = dvb_event_get_end_timestamp (DVB_EVENT (event1));
-	event2_time = dvb_event_get_end_timestamp (DVB_EVENT (event2));
+	event1_time = dvb_event_get_end_timestamp (event1);
+	event2_time = dvb_event_get_end_timestamp (event2);
 	if (event1_time < event2_time) {
 		return -1;
 	} else {
@@ -203,10 +231,17 @@ gint dvb_event_compare (DVBEvent* event1, DVBEvent* event2) {
          * event1 and event2 must be part of the same transport stream
          */
 gboolean dvb_event_equal (DVBEvent* event1, DVBEvent* event2) {
-	if (event1 == NULL || event2 == NULL) {
+	gboolean _tmp0;
+	_tmp0 = FALSE;
+	if (event1 == NULL) {
+		_tmp0 = TRUE;
+	} else {
+		_tmp0 = event2 == NULL;
+	}
+	if (_tmp0) {
 		return FALSE;
 	}
-	return (DVB_EVENT (event1)->id == DVB_EVENT (event2)->id);
+	return (event1->id == event2->id);
 }
 
 
@@ -215,7 +250,7 @@ gboolean dvb_event_equal (DVBEvent* event1, DVBEvent* event2) {
      */
 DVBEvent* dvb_event_construct (GType object_type) {
 	DVBEvent* self;
-	self = ((DVBEvent*) (g_type_create_instance (object_type)));
+	self = (DVBEvent*) g_type_create_instance (object_type);
 	return self;
 }
 
@@ -239,18 +274,18 @@ static GObject * dvb_event_constructor (GType type, guint n_construct_properties
 		GSList* _tmp1;
 		GSList* _tmp2;
 		_tmp0 = NULL;
-		self->audio_components = (_tmp0 = NULL, (self->audio_components == NULL ? NULL : (self->audio_components = (_g_slist_free_dvb_event_audio_component_unref (self->audio_components), NULL))), _tmp0);
+		self->audio_components = (_tmp0 = NULL, (self->audio_components == NULL) ? NULL : (self->audio_components = (_g_slist_free_dvb_event_audio_component_unref (self->audio_components), NULL)), _tmp0);
 		_tmp1 = NULL;
-		self->video_components = (_tmp1 = NULL, (self->video_components == NULL ? NULL : (self->video_components = (_g_slist_free_dvb_event_video_component_unref (self->video_components), NULL))), _tmp1);
+		self->video_components = (_tmp1 = NULL, (self->video_components == NULL) ? NULL : (self->video_components = (_g_slist_free_dvb_event_video_component_unref (self->video_components), NULL)), _tmp1);
 		_tmp2 = NULL;
-		self->teletext_components = (_tmp2 = NULL, (self->teletext_components == NULL ? NULL : (self->teletext_components = (_g_slist_free_dvb_event_teletext_component_unref (self->teletext_components), NULL))), _tmp2);
-		self->year = ((guint) (0));
-		self->month = ((guint) (0));
-		self->hour = ((guint) (0));
-		self->day = ((guint) (0));
-		self->minute = ((guint) (0));
-		self->second = ((guint) (0));
-		self->duration = ((guint) (0));
+		self->teletext_components = (_tmp2 = NULL, (self->teletext_components == NULL) ? NULL : (self->teletext_components = (_g_slist_free_dvb_event_teletext_component_unref (self->teletext_components), NULL)), _tmp2);
+		self->year = (guint) 0;
+		self->month = (guint) 0;
+		self->hour = (guint) 0;
+		self->day = (guint) 0;
+		self->minute = (guint) 0;
+		self->second = (guint) 0;
+		self->duration = (guint) 0;
 		self->running_status = DVB_EVENT_RUNNING_STATUS_UNDEFINED;
 	}
 	return obj;
@@ -259,7 +294,7 @@ static GObject * dvb_event_constructor (GType type, guint n_construct_properties
 
 DVBEventAudioComponent* dvb_event_audio_component_construct (GType object_type) {
 	DVBEventAudioComponent* self;
-	self = ((DVBEventAudioComponent*) (g_type_create_instance (object_type)));
+	self = (DVBEventAudioComponent*) g_type_create_instance (object_type);
 	return self;
 }
 
@@ -298,12 +333,13 @@ static gpointer dvb_event_value_audio_component_peek_pointer (const GValue* valu
 static gchar* dvb_event_value_audio_component_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
 	if (collect_values[0].v_pointer) {
 		DVBEventAudioComponent* object;
-		object = value->data[0].v_pointer;
+		object = collect_values[0].v_pointer;
 		if (object->parent_instance.g_class == NULL) {
 			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
-		} else if (!g_value_type_compatible (G_OBJECT_TYPE (object), G_VALUE_TYPE (value))) {
-			return g_strconcat ("invalid object type `", G_OBJECT_TYPE (object), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
+		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
+			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
 		}
+		value->data[0].v_pointer = dvb_event_audio_component_ref (object);
 	} else {
 		value->data[0].v_pointer = NULL;
 	}
@@ -315,6 +351,7 @@ static gchar* dvb_event_value_audio_component_lcopy_value (const GValue* value,
 	DVBEventAudioComponent** object_p;
 	object_p = collect_values[0].v_pointer;
 	if (!object_p) {
+		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
 	}
 	if (!value->data[0].v_pointer) {
 		*object_p = NULL;
@@ -403,14 +440,14 @@ void dvb_event_audio_component_unref (gpointer instance) {
 	self = instance;
 	if (g_atomic_int_dec_and_test (&self->ref_count)) {
 		DVB_EVENT_AUDIO_COMPONENT_GET_CLASS (self)->finalize (self);
-		g_type_free_instance (((GTypeInstance *) (self)));
+		g_type_free_instance ((GTypeInstance *) self);
 	}
 }
 
 
 DVBEventVideoComponent* dvb_event_video_component_construct (GType object_type) {
 	DVBEventVideoComponent* self;
-	self = ((DVBEventVideoComponent*) (g_type_create_instance (object_type)));
+	self = (DVBEventVideoComponent*) g_type_create_instance (object_type);
 	return self;
 }
 
@@ -449,12 +486,13 @@ static gpointer dvb_event_value_video_component_peek_pointer (const GValue* valu
 static gchar* dvb_event_value_video_component_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
 	if (collect_values[0].v_pointer) {
 		DVBEventVideoComponent* object;
-		object = value->data[0].v_pointer;
+		object = collect_values[0].v_pointer;
 		if (object->parent_instance.g_class == NULL) {
 			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
-		} else if (!g_value_type_compatible (G_OBJECT_TYPE (object), G_VALUE_TYPE (value))) {
-			return g_strconcat ("invalid object type `", G_OBJECT_TYPE (object), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
+		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
+			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
 		}
+		value->data[0].v_pointer = dvb_event_video_component_ref (object);
 	} else {
 		value->data[0].v_pointer = NULL;
 	}
@@ -466,6 +504,7 @@ static gchar* dvb_event_value_video_component_lcopy_value (const GValue* value,
 	DVBEventVideoComponent** object_p;
 	object_p = collect_values[0].v_pointer;
 	if (!object_p) {
+		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
 	}
 	if (!value->data[0].v_pointer) {
 		*object_p = NULL;
@@ -554,14 +593,14 @@ void dvb_event_video_component_unref (gpointer instance) {
 	self = instance;
 	if (g_atomic_int_dec_and_test (&self->ref_count)) {
 		DVB_EVENT_VIDEO_COMPONENT_GET_CLASS (self)->finalize (self);
-		g_type_free_instance (((GTypeInstance *) (self)));
+		g_type_free_instance ((GTypeInstance *) self);
 	}
 }
 
 
 DVBEventTeletextComponent* dvb_event_teletext_component_construct (GType object_type) {
 	DVBEventTeletextComponent* self;
-	self = ((DVBEventTeletextComponent*) (g_type_create_instance (object_type)));
+	self = (DVBEventTeletextComponent*) g_type_create_instance (object_type);
 	return self;
 }
 
@@ -600,12 +639,13 @@ static gpointer dvb_event_value_teletext_component_peek_pointer (const GValue* v
 static gchar* dvb_event_value_teletext_component_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
 	if (collect_values[0].v_pointer) {
 		DVBEventTeletextComponent* object;
-		object = value->data[0].v_pointer;
+		object = collect_values[0].v_pointer;
 		if (object->parent_instance.g_class == NULL) {
 			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
-		} else if (!g_value_type_compatible (G_OBJECT_TYPE (object), G_VALUE_TYPE (value))) {
-			return g_strconcat ("invalid object type `", G_OBJECT_TYPE (object), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
+		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
+			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
 		}
+		value->data[0].v_pointer = dvb_event_teletext_component_ref (object);
 	} else {
 		value->data[0].v_pointer = NULL;
 	}
@@ -617,6 +657,7 @@ static gchar* dvb_event_value_teletext_component_lcopy_value (const GValue* valu
 	DVBEventTeletextComponent** object_p;
 	object_p = collect_values[0].v_pointer;
 	if (!object_p) {
+		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
 	}
 	if (!value->data[0].v_pointer) {
 		*object_p = NULL;
@@ -705,7 +746,7 @@ void dvb_event_teletext_component_unref (gpointer instance) {
 	self = instance;
 	if (g_atomic_int_dec_and_test (&self->ref_count)) {
 		DVB_EVENT_TELETEXT_COMPONENT_GET_CLASS (self)->finalize (self);
-		g_type_free_instance (((GTypeInstance *) (self)));
+		g_type_free_instance ((GTypeInstance *) self);
 	}
 }
 
@@ -739,12 +780,13 @@ static gpointer dvb_value_event_peek_pointer (const GValue* value) {
 static gchar* dvb_value_event_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
 	if (collect_values[0].v_pointer) {
 		DVBEvent* object;
-		object = value->data[0].v_pointer;
+		object = collect_values[0].v_pointer;
 		if (object->parent_instance.g_class == NULL) {
 			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
-		} else if (!g_value_type_compatible (G_OBJECT_TYPE (object), G_VALUE_TYPE (value))) {
-			return g_strconcat ("invalid object type `", G_OBJECT_TYPE (object), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
+		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
+			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
 		}
+		value->data[0].v_pointer = dvb_event_ref (object);
 	} else {
 		value->data[0].v_pointer = NULL;
 	}
@@ -756,6 +798,7 @@ static gchar* dvb_value_event_lcopy_value (const GValue* value, guint n_collect_
 	DVBEvent** object_p;
 	object_p = collect_values[0].v_pointer;
 	if (!object_p) {
+		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
 	}
 	if (!value->data[0].v_pointer) {
 		*object_p = NULL;
@@ -818,9 +861,9 @@ static void dvb_event_finalize (DVBEvent* obj) {
 	self->name = (g_free (self->name), NULL);
 	self->description = (g_free (self->description), NULL);
 	self->extended_description = (g_free (self->extended_description), NULL);
-	(self->audio_components == NULL ? NULL : (self->audio_components = (_g_slist_free_dvb_event_audio_component_unref (self->audio_components), NULL)));
-	(self->video_components == NULL ? NULL : (self->video_components = (_g_slist_free_dvb_event_video_component_unref (self->video_components), NULL)));
-	(self->teletext_components == NULL ? NULL : (self->teletext_components = (_g_slist_free_dvb_event_teletext_component_unref (self->teletext_components), NULL)));
+	(self->audio_components == NULL) ? NULL : (self->audio_components = (_g_slist_free_dvb_event_audio_component_unref (self->audio_components), NULL));
+	(self->video_components == NULL) ? NULL : (self->video_components = (_g_slist_free_dvb_event_video_component_unref (self->video_components), NULL));
+	(self->teletext_components == NULL) ? NULL : (self->teletext_components = (_g_slist_free_dvb_event_teletext_component_unref (self->teletext_components), NULL));
 }
 
 
@@ -849,7 +892,7 @@ void dvb_event_unref (gpointer instance) {
 	self = instance;
 	if (g_atomic_int_dec_and_test (&self->ref_count)) {
 		DVB_EVENT_GET_CLASS (self)->finalize (self);
-		g_type_free_instance (((GTypeInstance *) (self)));
+		g_type_free_instance ((GTypeInstance *) self);
 	}
 }
 
